@@ -32,10 +32,12 @@ protected:
 	bool isAlpha;
 	unsigned int keycode;
 	TQString normalText;
-	TQString capsText;
 	TQString shiftText;
-	TQString altGrText;
+	TQString capsText;
 	TQString capsShiftText;
+	TQString capsAltGrText;
+	TQString capsAltGrShiftText;
+	TQString altGrText;
 	TQString altGrShiftText;
 	TQRect orig_size;
 
