@@ -30,15 +30,10 @@ class NumpadVButton : public VButton
 Q_OBJECT
   
 public:
-    NumpadVButton(TQWidget *parent = 0, const char *name = 0);
-    ~NumpadVButton();
+	NumpadVButton(TQWidget *parent = 0, const char *name = 0);
+	~NumpadVButton();
+
 	void numlockPressed(bool press);
-	void setKeyCode(unsigned int keycode, unsigned int n_keycode);
-
-private:
-	unsigned int numlock_code;
-	unsigned int cursor_code;
-
 };
 
 #endif
